@@ -1,4 +1,4 @@
-__version__ = "1.1.0"
+__version__ = "1.3.0"
 
 from _neworder_core import (
   Model,
@@ -11,3 +11,5 @@ from _neworder_core import (
   time, df, mpi, log, run, stats, checked, verbose
 ) # type: ignore
 from .domain import Edge, Domain, Space, StateGrid
+from .graph import GeospatialGraph
+from .mc import as_np
