@@ -3,24 +3,12 @@
 #include "Module.h"
 
 
-template<>
-std::string to_string_impl(char c)
-{
-  return std::string(1, c);
-}
-
-template<>
-std::string to_string_impl(const char* v)
-{
-  return std::string(v);
-}
-
-std::string to_string_impl(const std::string& v)
+std::string std::to_string(const std::string& v)
 {
   return v;
 }
 
-std::string to_string_impl(const py::object& o)
+std::string std::to_string(const py::object& o)
 {
   return py::str(o);
 }
