@@ -3,7 +3,7 @@
 #include "Log.h"
 #include "ArrayHelpers.h"
 #include "Timeline.h"
-#include <vector>
+#include <numpy/random/bitgen.h>
 #include <random>
 #include <algorithm>
 #include <cmath>
@@ -63,6 +63,16 @@ int32_t no::MonteCarlo::seed() const noexcept
   return m_seed;
 }
 
+void no::MonteCarlo::init_bitgen(py::capsule capsule)
+{
+  bitgen_t* bitgen(capsule);
+  bitgen->state = this;
+  bitgen->next_uint64 = [](void* p) { return static_cast<no::MonteCarlo*>(p)->raw(); };
+  bitgen->next_uint32 = [](void* p) { return static_cast<uint32_t>(static_cast<no::MonteCarlo*>(p)->raw()); };
+  bitgen->next_double = [](void* p) { return static_cast<no::MonteCarlo*>(p)->u01(); };
+  bitgen->next_raw = [](void* p) { return static_cast<no::MonteCarlo*>(p)->raw(); };
+}
+
 void no::MonteCarlo::reset() noexcept
 {
   m_prng.seed(m_seed);
@@ -75,14 +85,9 @@ std::string no::MonteCarlo::repr() const noexcept
 
 size_t no::MonteCarlo::state() const noexcept
 {
-// disable as causes segfault in mpi tests on travis OSX build
-#ifdef __APPLE__
-  return 0;
-#else
   std::ostringstream s;
   s << m_prng;
   return std::hash<std::string>{}(s.str());
-#endif
 }
 
 // raw unsigned 64-bit ints (for enabling numpy to use this generator)
